source("Gamma.r") # load the functions

# Simulating data

g   <- 3    # number of group
n   <- 600  # number of observation
mix <- NULL

x    <- NULL                               # samples matrix
pesi <- c(0.4,0.4,0.2)                     # group proportions
ng   <- rmultinom(1, n, prob = pesi)       # number of observations in each group

# Parameters that change according to the number of groups

m <- c(0.5,1.3,2.5)   # modes
v <- c(0.2,0.14,0.1)  # dispersion parameters ("v" in the paper)

#  Simulate the sample
for(l in 1:g) {
    x <- c(x,rgamma(ng[l],shape=m[l]/v[l]+1,scale=v[l]))  # create sample
    }
     
# Estimating mixture

INITmet  <- "BH"   # Initialization strategy: random, BH (Bump Hunting), manual
EMproc   <- "EM"   # EM-based procedure: EM, SEM and CEM
mix      <- gammamix(x,g=g,rr=100,initial=INITmet,nx=300,EMtype=EMproc)  # Estimation

# True and estimated parameters

pil   <- pesi
theta <- cbind(m,v)

pil 
theta

mix$pil
mix$theta

# Plot of the true (black) and estimated (red) mixture, in blue the kernel density estimation 

par(mai=c(0.85,0.85,0.5,0.01))
seqx  <- seq(0,max(x)*1.1,length.out= 10000)
plot(seqx,mixfungam(seqx, pesi=pil, parametri=theta, a=0, G=g ), type="l",xlab=expression(x),ylab="density",main="Comparison between global curves")
points(density(x),type="l",col="blue",lty=2) 
curve(mixfungam(x,mix$pil,mix$theta,a=0,G=g),add=T,col="red",lty=3) # If SEM is used the parameters of the last iteration are used
legend("bottom",c("true density", "kernel density", "gamma mixture"),col = c("black","blue","red"),lty = 1:3,cex=0.8,box.col="white",inset=0.05)

# Plot of the true (black) and estimated (red) components

par(mai=c(0.85,0.85,0.5,0.01))
curve(pil[1]*gammad(x,theta[1,1],theta[1,2],a=0),ylim=c(0,max(mixfungam(seqx, pesi=pil, parametri=theta, a=0, G=g ))),xlim=c(0,max(x)*1.2),ylab="density",main="comparison between component densities")
for(i in 2:g) {
  curve(pil[i]*gammad(x,theta[i,1],theta[i,2],a=0),add=T)
  }
for(i in 1:g) {
  curve(mix$pil[i]*gammad(x,mix$theta[i,1],mix$theta[i,2],a=0),add=T,col="red",lty=2)
}
legend("topright",c("true components","gamma components"),col = c("black","red"),lty = 1:2,cex=0.8,box.col="white",inset=0.01)

# Plot of the log-ikelihood in all iteration

par(mai=c(0.85,0.85,0.5,0.01))
if(EMproc == "CEM"){plot(mix$LgLc,type="l",main="complete log-likelihood vs. iterations")}     # The complete log-likelihood if CEM is used
if(EMproc == "EM" | EMproc == "SEM"){plot(mix$LgL,type="l",main="observed log-likelihood vs. iterations")}

